@@ -1,9 +1,9 @@
 ##' Export annotations of emuDB to TextGrid collection
 ##' 
-##' Exports the annotations of a emuDB to a TextGrid collection (.TextGrid and .wav file pairs).
-##' To avoid naming conflicts and not to loose the session information the session structure of 
-##' the database is kept in place by sub-folders that are named as the sessions where. 
-##' Due to the more complex annotation structure modeling capabilities of 
+##' Exports the annotations of an emuDB to a TextGrid collection (.TextGrid and .wav file pairs).
+##' To avoid naming conflicts and not to loose the session information, the session structure of 
+##' the database is kept in place (i.e. the TextGrid collection will have sub-folders that are named
+##' as the sessions were). Due to the more complex annotation structure modeling capabilities of 
 ##' the EMU-SDMS system, this export routine has to make several compromises on export which 
 ##' can lead to information loss. So use with caution and at own risk as reimporting the exported
 ##' data will mean that not all information can be recreated!
@@ -44,6 +44,8 @@
 export_TextGridCollection <- function(emuDBhandle, targetDir, sessionPattern = '.*', bundlePattern = '.*', 
                                       attributeDefinitionNames = NULL, verbose = TRUE) {
   
+  check_emuDBhandle(emuDBhandle)
+  
   dbConfig = load_DBconfig(emuDBhandle)
   
   allAttrNames = get_allAttributeNames(emuDBhandle)
